@@ -4,7 +4,7 @@
 %
 %    Copyright (C) 2013 SUPELEC
 %
-%    Author: Julien Bect  <julien.bect@supelec.fr>
+%    Author: Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -30,7 +30,7 @@ function y = xor(x1, x2)
 
 y = bsxfun(@xor, x1, x2);
 
-end % function xor
+end % function
 
 %!shared x, y, z
 %! x = floor (3 * rand (7, 2));
