@@ -1,10 +1,11 @@
-% SUBSASGN [overloaded base function]
+% SUBSASGN [overload base function]
 
 % Copyright Notice
 %
+%    Copyright (C) 2017 CentraleSupelec
 %    Copyright (C) 2013, 2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -32,7 +33,7 @@ if isa (x, 'stk_hrect')
     
     x.stk_dataframe = subsasgn (x.stk_dataframe, idx, value);
     
-    data = x.stk_dataframe.data;
+    data = get (x.stk_dataframe, 'data');
     if any (data(1, :) > data(2, :))
         stk_error ('Lower bounds cannot be larger than upperbounds', ...
             'IllegalAssigment');
@@ -44,4 +45,4 @@ else % value must be an stk_hrect object
     
 end
 
-end % function subsasgn
+end % function
