@@ -1,10 +1,12 @@
-% DOUBLE [overload base function]
+% DOUBLE [overload base function, deprecated]
+%
+% DEPRECATION WARNING: The use of .a structures is deprecated.
 
 % Copyright Notice
 %
-%    Copyright (C) 2013 SUPELEC
+%    Copyright (C) 2013, 2016 SUPELEC
 %
-%    Author: Julien Bect  <julien.bect@supelec.fr>
+%    Author: Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -30,4 +32,4 @@ function xdata = double (x)
 
 xdata = x.a;
 
-end % function double
+end % function
